# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sliverpb/sliver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..commonpb import common_pb2 as commonpb_dot_common__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15sliverpb/sliver.proto\x12\x08sliverpb\x1a\x15\x63ommonpb/common.proto"N\n\x08\x45nvelope\x12\n\n\x02ID\x18\x01 \x01(\x03\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\x12\x1a\n\x12UnknownMessageType\x18\x04 \x01(\x08"Q\n\x0b\x42\x65\x61\x63onTasks\x12\n\n\x02ID\x18\x01 \x01(\t\x12!\n\x05Tasks\x18\x02 \x03(\x0b\x32\x12.sliverpb.Envelope\x12\x13\n\x0bNextCheckin\x18\x03 \x01(\x03"\x9f\x02\n\x08Register\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08Hostname\x18\x02 \x01(\t\x12\x0c\n\x04Uuid\x18\x03 \x01(\t\x12\x10\n\x08Username\x18\x04 \x01(\t\x12\x0b\n\x03Uid\x18\x05 \x01(\t\x12\x0b\n\x03Gid\x18\x06 \x01(\t\x12\n\n\x02Os\x18\x07 \x01(\t\x12\x0c\n\x04\x41rch\x18\x08 \x01(\t\x12\x0b\n\x03Pid\x18\t \x01(\x05\x12\x10\n\x08\x46ilename\x18\n \x01(\t\x12\x10\n\x08\x41\x63tiveC2\x18\x0b \x01(\t\x12\x0f\n\x07Version\x18\x0c \x01(\t\x12\x19\n\x11ReconnectInterval\x18\r \x01(\x03\x12\x10\n\x08ProxyURL\x18\x0e \x01(\t\x12\x10\n\x08\x43onfigID\x18\x10 \x01(\t\x12\x0e\n\x06PeerID\x18\x11 \x01(\x03\x12\x0e\n\x06Locale\x18\x12 \x01(\t"y\n\x0e\x42\x65\x61\x63onRegister\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\x03\x12\x0e\n\x06Jitter\x18\x03 \x01(\x03\x12$\n\x08Register\x18\x04 \x01(\x0b\x32\x12.sliverpb.Register\x12\x13\n\x0bNextCheckin\x18\x05 \x01(\x03"C\n\x0fSessionRegister\x12\n\n\x02ID\x18\x01 \x01(\t\x12$\n\x08Register\x18\x02 \x01(\x0b\x32\x12.sliverpb.Register"s\n\x0bOpenSession\x12\x0b\n\x03\x43\x32s\x18\x01 \x03(\t\x12\r\n\x05\x44\x65lay\x18\x02 \x01(\x03\x12$\n\x08Response\x18\x08 \x01(\x0b\x32\x12.commonpb.Response\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"X\n\x0c\x43loseSession\x12$\n\x08Response\x18\x08 \x01(\x0b\x32\x12.commonpb.Response\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"_\n\x04Ping\x12\r\n\x05Nonce\x18\x01 \x01(\x05\x12$\n\x08Response\x18\x08 \x01(\x0b\x32\x12.commonpb.Response\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"<\n\x07KillReq\x12\r\n\x05\x46orce\x18\x01 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"+\n\x05PsReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"P\n\x02Ps\x12$\n\tProcesses\x18\x01 \x03(\x0b\x32\x11.commonpb.Process\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"N\n\x0cTerminateReq\x12\x0b\n\x03Pid\x18\x01 \x01(\x05\x12\r\n\x05\x46orce\x18\x02 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request">\n\tTerminate\x12\x0b\n\x03Pid\x18\x01 \x01(\x05\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"1\n\x0bIfconfigReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"_\n\x08Ifconfig\x12-\n\rNetInterfaces\x18\x01 \x03(\x0b\x32\x16.sliverpb.NetInterface\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"M\n\x0cNetInterface\x12\r\n\x05Index\x18\x01 \x01(\x05\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0b\n\x03MAC\x18\x03 \x01(\t\x12\x13\n\x0bIPAddresses\x18\x04 \x03(\t"9\n\x05LsReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x95\x01\n\x02Ls\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0e\n\x06\x45xists\x18\x02 \x01(\x08\x12!\n\x05\x46iles\x18\x03 \x03(\x0b\x32\x12.sliverpb.FileInfo\x12\x10\n\x08timezone\x18\x04 \x01(\t\x12\x16\n\x0etimezoneOffset\x18\x05 \x01(\x05\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"b\n\x08\x46ileInfo\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05IsDir\x18\x02 \x01(\x08\x12\x0c\n\x04Size\x18\x03 \x01(\x03\x12\x0f\n\x07ModTime\x18\x04 \x01(\x03\x12\x0c\n\x04Mode\x18\x05 \x01(\t\x12\x0c\n\x04Link\x18\x06 \x01(\t"9\n\x05\x43\x64Req\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request",\n\x06PwdReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"9\n\x03Pwd\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"[\n\x05RmReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x11\n\tRecursive\x18\x02 \x01(\x08\x12\r\n\x05\x46orce\x18\x03 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"8\n\x02Rm\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"E\n\x05MvReq\x12\x0b\n\x03Src\x18\x01 \x01(\t\x12\x0b\n\x03\x44st\x18\x02 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"D\n\x02Mv\x12\x0b\n\x03Src\x18\x01 \x01(\t\x12\x0b\n\x03\x44st\x18\x02 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"<\n\x08MkdirReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request";\n\x05Mkdir\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"m\n\x0b\x44ownloadReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\r\n\x05Start\x18\x02 \x01(\x03\x12\x0c\n\x04Stop\x18\x03 \x01(\x03\x12\x0f\n\x07Recurse\x18\x04 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\xc5\x01\n\x08\x44ownload\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07\x45ncoder\x18\x02 \x01(\t\x12\x0e\n\x06\x45xists\x18\x03 \x01(\x08\x12\r\n\x05Start\x18\x04 \x01(\x03\x12\x0c\n\x04Stop\x18\x05 \x01(\x03\x12\x0c\n\x04\x44\x61ta\x18\x06 \x01(\x0c\x12\r\n\x05IsDir\x18\x07 \x01(\x08\x12\x11\n\tReadFiles\x18\x08 \x01(\x05\x12\x17\n\x0fUnreadableFiles\x18\n \x01(\x05\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"k\n\tUploadReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07\x45ncoder\x18\x02 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\x12\r\n\x05IsIOC\x18\x04 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"<\n\x06Upload\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"R\n\x0eProcessDumpReq\x12\x0b\n\x03Pid\x18\x01 \x01(\x05\x12\x0f\n\x07Timeout\x18\x02 \x01(\x05\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"A\n\x0bProcessDump\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"c\n\x08RunAsReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"=\n\x05RunAs\x12\x0e\n\x06Output\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"F\n\x0eImpersonateReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"3\n\x0bImpersonate\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"2\n\x0cRevToSelfReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"1\n\tRevToSelf\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response":\n\x14\x43urrentTokenOwnerReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"I\n\x11\x43urrentTokenOwner\x12\x0e\n\x06Output\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"^\n\x12InvokeGetSystemReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x16\n\x0eHostingProcess\x18\x02 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"1\n\tGetSystem\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"f\n\x0cMakeTokenReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\x12\x0e\n\x06\x44omain\x18\x03 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"1\n\tMakeToken\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"k\n\x07TaskReq\x12\x0f\n\x07\x45ncoder\x18\x01 \x01(\t\x12\x10\n\x08RWXPages\x18\x02 \x01(\x08\x12\x0b\n\x03Pid\x18\x03 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request",\n\x04Task\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xaf\x02\n\x12\x45xecuteAssemblyReq\x12\x10\n\x08\x41ssembly\x18\x01 \x01(\x0c\x12\x11\n\tArguments\x18\x02 \x01(\t\x12\x0f\n\x07Process\x18\x03 \x01(\t\x12\r\n\x05IsDLL\x18\x04 \x01(\x08\x12\x0c\n\x04\x41rch\x18\x05 \x01(\t\x12\x11\n\tClassName\x18\x06 \x01(\t\x12\x0e\n\x06Method\x18\x07 \x01(\t\x12\x11\n\tAppDomain\x18\x08 \x01(\t\x12\x0c\n\x04PPid\x18\n \x01(\r\x12\x13\n\x0bProcessArgs\x18\x0b \x03(\t\x12\x11\n\tInProcess\x18\x0c \x01(\x08\x12\x0f\n\x07Runtime\x18\r \x01(\t\x12\x12\n\nAmsiBypass\x18\x0e \x01(\x08\x12\x11\n\tEtwBypass\x18\x0f \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x80\x01\n\x18InvokeExecuteAssemblyReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x0f\n\x07process\x18\x02 \x01(\t\x12\x0c\n\x04PPid\x18\n \x01(\r\x12\x13\n\x0bProcessArgs\x18\x0b \x03(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x9d\x01\n\x1eInvokeInProcExecuteAssemblyReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x11\n\tArguments\x18\x02 \x03(\t\x12\x0f\n\x07Runtime\x18\x03 \x01(\t\x12\x12\n\nAmsiBypass\x18\x04 \x01(\x08\x12\x11\n\tEtwBypass\x18\x05 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"G\n\x0f\x45xecuteAssembly\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"Q\n\x10InvokeMigrateReq\x12\x0b\n\x03Pid\x18\x01 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"@\n\x07Migrate\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\x8a\x01\n\nExecuteReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x02 \x03(\t\x12\x0e\n\x06Output\x18\x03 \x01(\x08\x12\x0e\n\x06Stdout\x18\x04 \x01(\t\x12\x0e\n\x06Stderr\x18\x05 \x01(\t\x12\x0c\n\x04PPid\x18\n \x01(\r\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\xa3\x01\n\x11\x45xecuteWindowsReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x02 \x03(\t\x12\x0e\n\x06Output\x18\x03 \x01(\x08\x12\x0e\n\x06Stdout\x18\x04 \x01(\t\x12\x0e\n\x06Stderr\x18\x05 \x01(\t\x12\x10\n\x08UseToken\x18\x06 \x01(\x08\x12\x0c\n\x04PPid\x18\n \x01(\r\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"l\n\x07\x45xecute\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06Stdout\x18\x02 \x01(\x0c\x12\x0e\n\x06Stderr\x18\x03 \x01(\x0c\x12\x0b\n\x03Pid\x18\x04 \x01(\r\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xc9\x01\n\x0bSideloadReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\t\x12\x12\n\nEntryPoint\x18\x04 \x01(\t\x12\x0c\n\x04Kill\x18\x05 \x01(\x08\x12\r\n\x05isDLL\x18\x06 \x01(\x08\x12\x11\n\tisUnicode\x18\x07 \x01(\x08\x12\x0c\n\x04PPid\x18\n \x01(\r\x12\x13\n\x0bProcessArgs\x18\x0b \x03(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"@\n\x08Sideload\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xad\x01\n\x11InvokeSpawnDllReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\t\x12\x12\n\nEntryPoint\x18\x04 \x01(\t\x12\x0c\n\x04Kill\x18\x05 \x01(\x08\x12\x0c\n\x04PPid\x18\n \x01(\r\x12\x13\n\x0bProcessArgs\x18\x0b \x03(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\xa3\x01\n\x0bSpawnDllReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0e\n\x06Offset\x18\x03 \x01(\r\x12\x0c\n\x04\x41rgs\x18\x04 \x01(\t\x12\x0c\n\x04Kill\x18\x05 \x01(\x08\x12\x0c\n\x04PPid\x18\n \x01(\r\x12\x13\n\x0bProcessArgs\x18\x0b \x03(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"@\n\x08SpawnDll\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"w\n\nNetstatReq\x12\x0b\n\x03TCP\x18\x01 \x01(\x08\x12\x0b\n\x03UDP\x18\x02 \x01(\x08\x12\x0b\n\x03IP4\x18\x03 \x01(\x08\x12\x0b\n\x03IP6\x18\x05 \x01(\x08\x12\x11\n\tListening\x18\x06 \x01(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\xf1\x01\n\x0cSockTabEntry\x12\x32\n\tLocalAddr\x18\x01 \x01(\x0b\x32\x1f.sliverpb.SockTabEntry.SockAddr\x12\x33\n\nRemoteAddr\x18\x02 \x01(\x0b\x32\x1f.sliverpb.SockTabEntry.SockAddr\x12\x0f\n\x07SkState\x18\x03 \x01(\t\x12\x0b\n\x03UID\x18\x04 \x01(\r\x12"\n\x07Process\x18\x05 \x01(\x0b\x32\x11.commonpb.Process\x12\x10\n\x08Protocol\x18\x06 \x01(\t\x1a$\n\x08SockAddr\x12\n\n\x02Ip\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r"X\n\x07Netstat\x12\'\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x16.sliverpb.SockTabEntry\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response":\n\x06\x45nvReq\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"T\n\x07\x45nvInfo\x12#\n\tVariables\x18\x01 \x03(\x0b\x32\x10.commonpb.EnvVar\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"S\n\tSetEnvReq\x12"\n\x08Variable\x18\x01 \x01(\x0b\x32\x10.commonpb.EnvVar\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request".\n\x06SetEnv\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"?\n\x0bUnsetEnvReq\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"0\n\x08UnsetEnv\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\x1d\n\x0e\x44NSSessionInit\x12\x0b\n\x03Key\x18\x01 \x01(\x0c"3\n\x07\x44NSPoll\x12(\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x18.sliverpb.DNSBlockHeader"*\n\x0e\x44NSBlockHeader\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\r"\x1e\n\x0fHTTPSessionInit\x12\x0b\n\x03Key\x18\x01 \x01(\x0c"3\n\rScreenshotReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"@\n\nScreenshot\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\x9c\x01\n\x0fStartServiceReq\x12\x13\n\x0bServiceName\x18\x01 \x01(\t\x12\x1a\n\x12ServiceDescription\x18\x02 \x01(\t\x12\x0f\n\x07\x42inPath\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12\x11\n\tArguments\x18\x05 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"3\n\x0bServiceInfo\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"7\n\x0eServiceInfoReq\x12\x13\n\x0bServiceName\x18\x01 \x01(\t\x12\x10\n\x08Hostname\x18\x02 \x01(\t"c\n\x0eStopServiceReq\x12-\n\x0bServiceInfo\x18\x01 \x01(\x0b\x32\x18.sliverpb.ServiceInfoReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"e\n\x10RemoveServiceReq\x12-\n\x0bServiceInfo\x18\x01 \x01(\x0b\x32\x18.sliverpb.ServiceInfoReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"X\n\x0b\x42\x61\x63kdoorReq\x12\x10\n\x08\x46ilePath\x18\x01 \x01(\t\x12\x13\n\x0bProfileName\x18\x02 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"0\n\x08\x42\x61\x63kdoor\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"p\n\x0fRegistryReadReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"C\n\x0cRegistryRead\x12\r\n\x05Value\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xcf\x01\n\x10RegistryWriteReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12\x13\n\x0bStringValue\x18\x05 \x01(\t\x12\x11\n\tByteValue\x18\x06 \x01(\x0c\x12\x12\n\nDWordValue\x18\x07 \x01(\r\x12\x12\n\nQWordValue\x18\x08 \x01(\x04\x12\x0c\n\x04Type\x18\n \x01(\r\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"5\n\rRegistryWrite\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"u\n\x14RegistryCreateKeyReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"9\n\x11RegistryCreateKey\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"u\n\x14RegistryDeleteKeyReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"9\n\x11RegistryDeleteKey\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"i\n\x15RegistrySubKeyListReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"K\n\x12RegistrySubKeyList\x12\x0f\n\x07Subkeys\x18\x01 \x03(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"i\n\x15RegistryListValuesReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"N\n\x12RegistryValuesList\x12\x12\n\nValueNames\x18\x01 \x03(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"1\n\x06Tunnel\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\x11\n\tSessionID\x18\t \x01(\t"\xbf\x01\n\nTunnelData\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43losed\x18\x02 \x01(\x08\x12\x10\n\x08Sequence\x18\x03 \x01(\x04\x12\x0b\n\x03\x41\x63k\x18\x04 \x01(\x04\x12\x0e\n\x06Resend\x18\x05 \x01(\x08\x12\x15\n\rCreateReverse\x18\x06 \x01(\x08\x12$\n\x08rportfwd\x18\x07 \x01(\x0b\x32\x12.sliverpb.RPortfwd\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\x11\n\tSessionID\x18\t \x01(\t"r\n\x08ShellReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x11\n\tEnablePTY\x18\x02 \x01(\x08\x12\x0b\n\x03Pid\x18\x03 \x01(\r\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"q\n\x05Shell\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x11\n\tEnablePTY\x18\x02 \x01(\x08\x12\x0b\n\x03Pid\x18\x03 \x01(\r\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"t\n\nPortfwdReq\x12\x0c\n\x04Port\x18\x01 \x01(\r\x12\x10\n\x08Protocol\x18\x02 \x01(\x05\x12\x0c\n\x04Host\x18\x03 \x01(\t\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"s\n\x07Portfwd\x12\x0c\n\x04Port\x18\x01 \x01(\r\x12\x10\n\x08Protocol\x18\x02 \x01(\x05\x12\x0c\n\x04Host\x18\x03 \x01(\t\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"0\n\x05Socks\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\x11\n\tSessionID\x18\t \x01(\t"\x9c\x01\n\tSocksData\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x11\n\tCloseConn\x18\x02 \x01(\x08\x12\x10\n\x08Username\x18\x03 \x01(\t\x12\x10\n\x08Password\x18\x04 \x01(\t\x12\x10\n\x08Sequence\x18\x05 \x01(\x04\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x84\x01\n\x15PivotStartListenerReq\x12!\n\x04Type\x18\x01 \x01(\x0e\x32\x13.sliverpb.PivotType\x12\x13\n\x0b\x42indAddress\x18\x02 \x01(\t\x12\x0f\n\x07Options\x18\x03 \x03(\x08\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"F\n\x14PivotStopListenerReq\x12\n\n\x02ID\x18\x01 \x01(\r\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\xa1\x01\n\rPivotListener\x12\n\n\x02ID\x18\x01 \x01(\r\x12!\n\x04Type\x18\x02 \x01(\x0e\x32\x13.sliverpb.PivotType\x12\x13\n\x0b\x42indAddress\x18\x03 \x01(\t\x12&\n\x06Pivots\x18\x04 \x03(\x0b\x32\x16.sliverpb.NetConnPivot\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"c\n\nPivotHello\x12\x11\n\tPublicKey\x18\x01 \x01(\x0c\x12\x12\n\x06PeerID\x18\x02 \x01(\x03\x42\x02\x30\x01\x12\x1a\n\x12PublicKeySignature\x18\x03 \x01(\t\x12\x12\n\nSessionKey\x18\x04 \x01(\x0c">\n\x16PivotServerKeyExchange\x12\x10\n\x08OriginID\x18\x01 \x01(\x03\x12\x12\n\nSessionKey\x18\x02 \x01(\x0c"-\n\tPivotPeer\x12\x12\n\x06PeerID\x18\x01 \x01(\x03\x42\x02\x30\x01\x12\x0c\n\x04Name\x18\x02 \x01(\t"\x82\x01\n\x11PivotPeerEnvelope\x12"\n\x05Peers\x18\x01 \x03(\x0b\x32\x13.sliverpb.PivotPeer\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x16\n\x0ePivotSessionID\x18\x03 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12\x15\n\rPeerFailureAt\x18\x05 \x01(\x03"\x1a\n\tPivotPing\x12\r\n\x05Nonce\x18\x01 \x01(\r"9\n\x0cNetConnPivot\x12\x12\n\x06PeerID\x18\x01 \x01(\x03\x42\x02\x30\x01\x12\x15\n\rRemoteAddress\x18\x02 \x01(\t"\\\n\x10PivotPeerFailure\x12\x12\n\x06PeerID\x18\x01 \x01(\x03\x42\x02\x30\x01\x12\'\n\x04Type\x18\x02 \x01(\x0e\x32\x19.sliverpb.PeerFailureType\x12\x0b\n\x03\x45rr\x18\x03 \x01(\t"7\n\x11PivotListenersReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"b\n\x0ePivotListeners\x12*\n\tListeners\x18\x01 \x03(\x0b\x32\x17.sliverpb.PivotListener\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"e\n\x15WGPortForwardStartReq\x12\x11\n\tLocalPort\x18\x01 \x01(\x05\x12\x15\n\rRemoteAddress\x18\x02 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"b\n\rWGPortForward\x12+\n\tForwarder\x18\x01 \x01(\x0b\x32\x18.sliverpb.WGTCPForwarder\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"F\n\x14WGPortForwardStopReq\x12\n\n\x02ID\x18\x01 \x01(\x05\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"C\n\x0fWGSocksStartReq\x12\x0c\n\x04Port\x18\x01 \x01(\x05\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"X\n\x07WGSocks\x12\'\n\x06Server\x18\x01 \x01(\x0b\x32\x17.sliverpb.WGSocksServer\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"@\n\x0eWGSocksStopReq\x12\n\n\x02ID\x18\x01 \x01(\x05\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"8\n\x12WGTCPForwardersReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"7\n\x11WGSocksServersReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"C\n\x0eWGTCPForwarder\x12\n\n\x02ID\x18\x01 \x01(\x05\x12\x11\n\tLocalAddr\x18\x02 \x01(\t\x12\x12\n\nRemoteAddr\x18\x03 \x01(\t".\n\rWGSocksServer\x12\n\n\x02ID\x18\x01 \x01(\x05\x12\x11\n\tLocalAddr\x18\x02 \x01(\t"`\n\x0eWGSocksServers\x12(\n\x07Servers\x18\x01 \x03(\x0b\x32\x17.sliverpb.WGSocksServer\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"e\n\x0fWGTCPForwarders\x12,\n\nForwarders\x18\x01 \x03(\x0b\x32\x18.sliverpb.WGTCPForwarder\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"}\n\x0eReconfigureReq\x12\x19\n\x11ReconnectInterval\x18\x01 \x01(\x03\x12\x16\n\x0e\x42\x65\x61\x63onInterval\x18\x02 \x01(\x03\x12\x14\n\x0c\x42\x65\x61\x63onJitter\x18\x03 \x01(\x03\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"3\n\x0bReconfigure\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"K\n\x0fPollIntervalReq\x12\x14\n\x0cPollInterval\x18\x01 \x01(\x03\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"4\n\x0cPollInterval\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xca\x01\n\rSSHCommandReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12\x10\n\x08Hostname\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0f\n\x07\x43ommand\x18\x04 \x01(\t\x12\x10\n\x08Password\x18\x05 \x01(\t\x12\x0f\n\x07PrivKey\x18\x06 \x01(\x0c\x12\x10\n\x08Krb5Conf\x18\x07 \x01(\t\x12\x0e\n\x06Keytab\x18\x08 \x01(\x0c\x12\r\n\x05Realm\x18\n \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"R\n\nSSHCommand\x12\x0e\n\x06StdOut\x18\x01 \x01(\t\x12\x0e\n\x06StdErr\x18\x02 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"1\n\x0bGetPrivsReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x8d\x01\n\x15WindowsPrivilegeEntry\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x45nabled\x18\x03 \x01(\x08\x12\x18\n\x10\x45nabledByDefault\x18\x04 \x01(\x08\x12\x0f\n\x07Removed\x18\x05 \x01(\x08\x12\x15\n\rUsedForAccess\x18\x06 \x01(\x08"\x92\x01\n\x08GetPrivs\x12\x31\n\x08PrivInfo\x18\x01 \x03(\x0b\x32\x1f.sliverpb.WindowsPrivilegeEntry\x12\x18\n\x10ProcessIntegrity\x18\x02 \x01(\t\x12\x13\n\x0bProcessName\x18\x03 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"p\n\x14RegisterExtensionReq\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12\n\n\x02OS\x18\x03 \x01(\t\x12\x0c\n\x04Init\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"9\n\x11RegisterExtension\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"w\n\x10\x43\x61llExtensionReq\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x0bServerStore\x18\x02 \x01(\x08\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\x0c\x12\x0e\n\x06\x45xport\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"Z\n\rCallExtension\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12\x13\n\x0bServerStore\x18\x02 \x01(\x08\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"7\n\x11ListExtensionsReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"E\n\x0eListExtensions\x12\r\n\x05Names\x18\x01 \x03(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"I\n\x17RportFwdStopListenerReq\x12\n\n\x02ID\x18\x01 \x01(\r\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x92\x01\n\x18RportFwdStartListenerReq\x12\x13\n\x0b\x42indAddress\x18\x01 \x01(\t\x12\x10\n\x08\x42indPort\x18\x02 \x01(\r\x12\x13\n\x0b\x66orwardPort\x18\x03 \x01(\r\x12\x16\n\x0e\x66orwardAddress\x18\x04 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x98\x01\n\x10RportFwdListener\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x13\n\x0b\x42indAddress\x18\x02 \x01(\t\x12\x10\n\x08\x62indPort\x18\x03 \x01(\r\x12\x16\n\x0e\x66orwardAddress\x18\x04 \x01(\t\x12\x13\n\x0b\x66orwardPort\x18\x05 \x01(\r\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"h\n\x11RportFwdListeners\x12-\n\tListeners\x18\x01 \x03(\x0b\x32\x1a.sliverpb.RportFwdListener\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response":\n\x14RportFwdListenersReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"t\n\x08RPortfwd\x12\x0c\n\x04Port\x18\x01 \x01(\r\x12\x10\n\x08Protocol\x18\x02 \x01(\x05\x12\x0c\n\x04Host\x18\x03 \x01(\t\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"u\n\x0bRPortfwdReq\x12\x0c\n\x04Port\x18\x01 \x01(\r\x12\x10\n\x08Protocol\x18\x02 \x01(\x05\x12\x0c\n\x04Host\x18\x03 \x01(\t\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request*I\n\x0cRegistryType\x12\x0b\n\x07Unknown\x10\x00\x12\n\n\x06\x42inary\x10\x01\x12\n\n\x06String\x10\x02\x12\t\n\x05\x44WORD\x10\x03\x12\t\n\x05QWORD\x10\x04*,\n\tPivotType\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x12\r\n\tNamedPipe\x10\x02*3\n\x0fPeerFailureType\x12\x10\n\x0cSEND_FAILURE\x10\x00\x12\x0e\n\nDISCONNECT\x10\x01\x42/Z-github.com/bishopfox/sliver/protobuf/sliverpbb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "sliverpb.sliver_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z-github.com/bishopfox/sliver/protobuf/sliverpb"
    _TUNNEL.fields_by_name["TunnelID"]._options = None
    _TUNNEL.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _TUNNELDATA.fields_by_name["TunnelID"]._options = None
    _TUNNELDATA.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _SHELLREQ.fields_by_name["TunnelID"]._options = None
    _SHELLREQ.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _SHELL.fields_by_name["TunnelID"]._options = None
    _SHELL.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _PORTFWDREQ.fields_by_name["TunnelID"]._options = None
    _PORTFWDREQ.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _PORTFWD.fields_by_name["TunnelID"]._options = None
    _PORTFWD.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _SOCKS.fields_by_name["TunnelID"]._options = None
    _SOCKS.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _SOCKSDATA.fields_by_name["TunnelID"]._options = None
    _SOCKSDATA.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _PIVOTHELLO.fields_by_name["PeerID"]._options = None
    _PIVOTHELLO.fields_by_name["PeerID"]._serialized_options = b"0\001"
    _PIVOTPEER.fields_by_name["PeerID"]._options = None
    _PIVOTPEER.fields_by_name["PeerID"]._serialized_options = b"0\001"
    _NETCONNPIVOT.fields_by_name["PeerID"]._options = None
    _NETCONNPIVOT.fields_by_name["PeerID"]._serialized_options = b"0\001"
    _PIVOTPEERFAILURE.fields_by_name["PeerID"]._options = None
    _PIVOTPEERFAILURE.fields_by_name["PeerID"]._serialized_options = b"0\001"
    _RPORTFWD.fields_by_name["TunnelID"]._options = None
    _RPORTFWD.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _RPORTFWDREQ.fields_by_name["TunnelID"]._options = None
    _RPORTFWDREQ.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _REGISTRYTYPE._serialized_start = 14051
    _REGISTRYTYPE._serialized_end = 14124
    _PIVOTTYPE._serialized_start = 14126
    _PIVOTTYPE._serialized_end = 14170
    _PEERFAILURETYPE._serialized_start = 14172
    _PEERFAILURETYPE._serialized_end = 14223
    _ENVELOPE._serialized_start = 58
    _ENVELOPE._serialized_end = 136
    _BEACONTASKS._serialized_start = 138
    _BEACONTASKS._serialized_end = 219
    _REGISTER._serialized_start = 222
    _REGISTER._serialized_end = 509
    _BEACONREGISTER._serialized_start = 511
    _BEACONREGISTER._serialized_end = 632
    _SESSIONREGISTER._serialized_start = 634
    _SESSIONREGISTER._serialized_end = 701
    _OPENSESSION._serialized_start = 703
    _OPENSESSION._serialized_end = 818
    _CLOSESESSION._serialized_start = 820
    _CLOSESESSION._serialized_end = 908
    _PING._serialized_start = 910
    _PING._serialized_end = 1005
    _KILLREQ._serialized_start = 1007
    _KILLREQ._serialized_end = 1067
    _PSREQ._serialized_start = 1069
    _PSREQ._serialized_end = 1112
    _PS._serialized_start = 1114
    _PS._serialized_end = 1194
    _TERMINATEREQ._serialized_start = 1196
    _TERMINATEREQ._serialized_end = 1274
    _TERMINATE._serialized_start = 1276
    _TERMINATE._serialized_end = 1338
    _IFCONFIGREQ._serialized_start = 1340
    _IFCONFIGREQ._serialized_end = 1389
    _IFCONFIG._serialized_start = 1391
    _IFCONFIG._serialized_end = 1486
    _NETINTERFACE._serialized_start = 1488
    _NETINTERFACE._serialized_end = 1565
    _LSREQ._serialized_start = 1567
    _LSREQ._serialized_end = 1624
    _LS._serialized_start = 1627
    _LS._serialized_end = 1776
    _FILEINFO._serialized_start = 1778
    _FILEINFO._serialized_end = 1876
    _CDREQ._serialized_start = 1878
    _CDREQ._serialized_end = 1935
    _PWDREQ._serialized_start = 1937
    _PWDREQ._serialized_end = 1981
    _PWD._serialized_start = 1983
    _PWD._serialized_end = 2040
    _RMREQ._serialized_start = 2042
    _RMREQ._serialized_end = 2133
    _RM._serialized_start = 2135
    _RM._serialized_end = 2191
    _MVREQ._serialized_start = 2193
    _MVREQ._serialized_end = 2262
    _MV._serialized_start = 2264
    _MV._serialized_end = 2332
    _MKDIRREQ._serialized_start = 2334
    _MKDIRREQ._serialized_end = 2394
    _MKDIR._serialized_start = 2396
    _MKDIR._serialized_end = 2455
    _DOWNLOADREQ._serialized_start = 2457
    _DOWNLOADREQ._serialized_end = 2566
    _DOWNLOAD._serialized_start = 2569
    _DOWNLOAD._serialized_end = 2766
    _UPLOADREQ._serialized_start = 2768
    _UPLOADREQ._serialized_end = 2875
    _UPLOAD._serialized_start = 2877
    _UPLOAD._serialized_end = 2937
    _PROCESSDUMPREQ._serialized_start = 2939
    _PROCESSDUMPREQ._serialized_end = 3021
    _PROCESSDUMP._serialized_start = 3023
    _PROCESSDUMP._serialized_end = 3088
    _RUNASREQ._serialized_start = 3090
    _RUNASREQ._serialized_end = 3189
    _RUNAS._serialized_start = 3191
    _RUNAS._serialized_end = 3252
    _IMPERSONATEREQ._serialized_start = 3254
    _IMPERSONATEREQ._serialized_end = 3324
    _IMPERSONATE._serialized_start = 3326
    _IMPERSONATE._serialized_end = 3377
    _REVTOSELFREQ._serialized_start = 3379
    _REVTOSELFREQ._serialized_end = 3429
    _REVTOSELF._serialized_start = 3431
    _REVTOSELF._serialized_end = 3480
    _CURRENTTOKENOWNERREQ._serialized_start = 3482
    _CURRENTTOKENOWNERREQ._serialized_end = 3540
    _CURRENTTOKENOWNER._serialized_start = 3542
    _CURRENTTOKENOWNER._serialized_end = 3615
    _INVOKEGETSYSTEMREQ._serialized_start = 3617
    _INVOKEGETSYSTEMREQ._serialized_end = 3711
    _GETSYSTEM._serialized_start = 3713
    _GETSYSTEM._serialized_end = 3762
    _MAKETOKENREQ._serialized_start = 3764
    _MAKETOKENREQ._serialized_end = 3866
    _MAKETOKEN._serialized_start = 3868
    _MAKETOKEN._serialized_end = 3917
    _TASKREQ._serialized_start = 3919
    _TASKREQ._serialized_end = 4026
    _TASK._serialized_start = 4028
    _TASK._serialized_end = 4072
    _EXECUTEASSEMBLYREQ._serialized_start = 4075
    _EXECUTEASSEMBLYREQ._serialized_end = 4378
    _INVOKEEXECUTEASSEMBLYREQ._serialized_start = 4381
    _INVOKEEXECUTEASSEMBLYREQ._serialized_end = 4509
    _INVOKEINPROCEXECUTEASSEMBLYREQ._serialized_start = 4512
    _INVOKEINPROCEXECUTEASSEMBLYREQ._serialized_end = 4669
    _EXECUTEASSEMBLY._serialized_start = 4671
    _EXECUTEASSEMBLY._serialized_end = 4742
    _INVOKEMIGRATEREQ._serialized_start = 4744
    _INVOKEMIGRATEREQ._serialized_end = 4825
    _MIGRATE._serialized_start = 4827
    _MIGRATE._serialized_end = 4891
    _EXECUTEREQ._serialized_start = 4894
    _EXECUTEREQ._serialized_end = 5032
    _EXECUTEWINDOWSREQ._serialized_start = 5035
    _EXECUTEWINDOWSREQ._serialized_end = 5198
    _EXECUTE._serialized_start = 5200
    _EXECUTE._serialized_end = 5308
    _SIDELOADREQ._serialized_start = 5311
    _SIDELOADREQ._serialized_end = 5512
    _SIDELOAD._serialized_start = 5514
    _SIDELOAD._serialized_end = 5578
    _INVOKESPAWNDLLREQ._serialized_start = 5581
    _INVOKESPAWNDLLREQ._serialized_end = 5754
    _SPAWNDLLREQ._serialized_start = 5757
    _SPAWNDLLREQ._serialized_end = 5920
    _SPAWNDLL._serialized_start = 5922
    _SPAWNDLL._serialized_end = 5986
    _NETSTATREQ._serialized_start = 5988
    _NETSTATREQ._serialized_end = 6107
    _SOCKTABENTRY._serialized_start = 6110
    _SOCKTABENTRY._serialized_end = 6351
    _SOCKTABENTRY_SOCKADDR._serialized_start = 6315
    _SOCKTABENTRY_SOCKADDR._serialized_end = 6351
    _NETSTAT._serialized_start = 6353
    _NETSTAT._serialized_end = 6441
    _ENVREQ._serialized_start = 6443
    _ENVREQ._serialized_end = 6501
    _ENVINFO._serialized_start = 6503
    _ENVINFO._serialized_end = 6587
    _SETENVREQ._serialized_start = 6589
    _SETENVREQ._serialized_end = 6672
    _SETENV._serialized_start = 6674
    _SETENV._serialized_end = 6720
    _UNSETENVREQ._serialized_start = 6722
    _UNSETENVREQ._serialized_end = 6785
    _UNSETENV._serialized_start = 6787
    _UNSETENV._serialized_end = 6835
    _DNSSESSIONINIT._serialized_start = 6837
    _DNSSESSIONINIT._serialized_end = 6866
    _DNSPOLL._serialized_start = 6868
    _DNSPOLL._serialized_end = 6919
    _DNSBLOCKHEADER._serialized_start = 6921
    _DNSBLOCKHEADER._serialized_end = 6963
    _HTTPSESSIONINIT._serialized_start = 6965
    _HTTPSESSIONINIT._serialized_end = 6995
    _SCREENSHOTREQ._serialized_start = 6997
    _SCREENSHOTREQ._serialized_end = 7048
    _SCREENSHOT._serialized_start = 7050
    _SCREENSHOT._serialized_end = 7114
    _STARTSERVICEREQ._serialized_start = 7117
    _STARTSERVICEREQ._serialized_end = 7273
    _SERVICEINFO._serialized_start = 7275
    _SERVICEINFO._serialized_end = 7326
    _SERVICEINFOREQ._serialized_start = 7328
    _SERVICEINFOREQ._serialized_end = 7383
    _STOPSERVICEREQ._serialized_start = 7385
    _STOPSERVICEREQ._serialized_end = 7484
    _REMOVESERVICEREQ._serialized_start = 7486
    _REMOVESERVICEREQ._serialized_end = 7587
    _BACKDOORREQ._serialized_start = 7589
    _BACKDOORREQ._serialized_end = 7677
    _BACKDOOR._serialized_start = 7679
    _BACKDOOR._serialized_end = 7727
    _REGISTRYREADREQ._serialized_start = 7729
    _REGISTRYREADREQ._serialized_end = 7841
    _REGISTRYREAD._serialized_start = 7843
    _REGISTRYREAD._serialized_end = 7910
    _REGISTRYWRITEREQ._serialized_start = 7913
    _REGISTRYWRITEREQ._serialized_end = 8120
    _REGISTRYWRITE._serialized_start = 8122
    _REGISTRYWRITE._serialized_end = 8175
    _REGISTRYCREATEKEYREQ._serialized_start = 8177
    _REGISTRYCREATEKEYREQ._serialized_end = 8294
    _REGISTRYCREATEKEY._serialized_start = 8296
    _REGISTRYCREATEKEY._serialized_end = 8353
    _REGISTRYDELETEKEYREQ._serialized_start = 8355
    _REGISTRYDELETEKEYREQ._serialized_end = 8472
    _REGISTRYDELETEKEY._serialized_start = 8474
    _REGISTRYDELETEKEY._serialized_end = 8531
    _REGISTRYSUBKEYLISTREQ._serialized_start = 8533
    _REGISTRYSUBKEYLISTREQ._serialized_end = 8638
    _REGISTRYSUBKEYLIST._serialized_start = 8640
    _REGISTRYSUBKEYLIST._serialized_end = 8715
    _REGISTRYLISTVALUESREQ._serialized_start = 8717
    _REGISTRYLISTVALUESREQ._serialized_end = 8822
    _REGISTRYVALUESLIST._serialized_start = 8824
    _REGISTRYVALUESLIST._serialized_end = 8902
    _TUNNEL._serialized_start = 8904
    _TUNNEL._serialized_end = 8953
    _TUNNELDATA._serialized_start = 8956
    _TUNNELDATA._serialized_end = 9147
    _SHELLREQ._serialized_start = 9149
    _SHELLREQ._serialized_end = 9263
    _SHELL._serialized_start = 9265
    _SHELL._serialized_end = 9378
    _PORTFWDREQ._serialized_start = 9380
    _PORTFWDREQ._serialized_end = 9496
    _PORTFWD._serialized_start = 9498
    _PORTFWD._serialized_end = 9613
    _SOCKS._serialized_start = 9615
    _SOCKS._serialized_end = 9663
    _SOCKSDATA._serialized_start = 9666
    _SOCKSDATA._serialized_end = 9822
    _PIVOTSTARTLISTENERREQ._serialized_start = 9825
    _PIVOTSTARTLISTENERREQ._serialized_end = 9957
    _PIVOTSTOPLISTENERREQ._serialized_start = 9959
    _PIVOTSTOPLISTENERREQ._serialized_end = 10029
    _PIVOTLISTENER._serialized_start = 10032
    _PIVOTLISTENER._serialized_end = 10193
    _PIVOTHELLO._serialized_start = 10195
    _PIVOTHELLO._serialized_end = 10294
    _PIVOTSERVERKEYEXCHANGE._serialized_start = 10296
    _PIVOTSERVERKEYEXCHANGE._serialized_end = 10358
    _PIVOTPEER._serialized_start = 10360
    _PIVOTPEER._serialized_end = 10405
    _PIVOTPEERENVELOPE._serialized_start = 10408
    _PIVOTPEERENVELOPE._serialized_end = 10538
    _PIVOTPING._serialized_start = 10540
    _PIVOTPING._serialized_end = 10566
    _NETCONNPIVOT._serialized_start = 10568
    _NETCONNPIVOT._serialized_end = 10625
    _PIVOTPEERFAILURE._serialized_start = 10627
    _PIVOTPEERFAILURE._serialized_end = 10719
    _PIVOTLISTENERSREQ._serialized_start = 10721
    _PIVOTLISTENERSREQ._serialized_end = 10776
    _PIVOTLISTENERS._serialized_start = 10778
    _PIVOTLISTENERS._serialized_end = 10876
    _WGPORTFORWARDSTARTREQ._serialized_start = 10878
    _WGPORTFORWARDSTARTREQ._serialized_end = 10979
    _WGPORTFORWARD._serialized_start = 10981
    _WGPORTFORWARD._serialized_end = 11079
    _WGPORTFORWARDSTOPREQ._serialized_start = 11081
    _WGPORTFORWARDSTOPREQ._serialized_end = 11151
    _WGSOCKSSTARTREQ._serialized_start = 11153
    _WGSOCKSSTARTREQ._serialized_end = 11220
    _WGSOCKS._serialized_start = 11222
    _WGSOCKS._serialized_end = 11310
    _WGSOCKSSTOPREQ._serialized_start = 11312
    _WGSOCKSSTOPREQ._serialized_end = 11376
    _WGTCPFORWARDERSREQ._serialized_start = 11378
    _WGTCPFORWARDERSREQ._serialized_end = 11434
    _WGSOCKSSERVERSREQ._serialized_start = 11436
    _WGSOCKSSERVERSREQ._serialized_end = 11491
    _WGTCPFORWARDER._serialized_start = 11493
    _WGTCPFORWARDER._serialized_end = 11560
    _WGSOCKSSERVER._serialized_start = 11562
    _WGSOCKSSERVER._serialized_end = 11608
    _WGSOCKSSERVERS._serialized_start = 11610
    _WGSOCKSSERVERS._serialized_end = 11706
    _WGTCPFORWARDERS._serialized_start = 11708
    _WGTCPFORWARDERS._serialized_end = 11809
    _RECONFIGUREREQ._serialized_start = 11811
    _RECONFIGUREREQ._serialized_end = 11936
    _RECONFIGURE._serialized_start = 11938
    _RECONFIGURE._serialized_end = 11989
    _POLLINTERVALREQ._serialized_start = 11991
    _POLLINTERVALREQ._serialized_end = 12066
    _POLLINTERVAL._serialized_start = 12068
    _POLLINTERVAL._serialized_end = 12120
    _SSHCOMMANDREQ._serialized_start = 12123
    _SSHCOMMANDREQ._serialized_end = 12325
    _SSHCOMMAND._serialized_start = 12327
    _SSHCOMMAND._serialized_end = 12409
    _GETPRIVSREQ._serialized_start = 12411
    _GETPRIVSREQ._serialized_end = 12460
    _WINDOWSPRIVILEGEENTRY._serialized_start = 12463
    _WINDOWSPRIVILEGEENTRY._serialized_end = 12604
    _GETPRIVS._serialized_start = 12607
    _GETPRIVS._serialized_end = 12753
    _REGISTEREXTENSIONREQ._serialized_start = 12755
    _REGISTEREXTENSIONREQ._serialized_end = 12867
    _REGISTEREXTENSION._serialized_start = 12869
    _REGISTEREXTENSION._serialized_end = 12926
    _CALLEXTENSIONREQ._serialized_start = 12928
    _CALLEXTENSIONREQ._serialized_end = 13047
    _CALLEXTENSION._serialized_start = 13049
    _CALLEXTENSION._serialized_end = 13139
    _LISTEXTENSIONSREQ._serialized_start = 13141
    _LISTEXTENSIONSREQ._serialized_end = 13196
    _LISTEXTENSIONS._serialized_start = 13198
    _LISTEXTENSIONS._serialized_end = 13267
    _RPORTFWDSTOPLISTENERREQ._serialized_start = 13269
    _RPORTFWDSTOPLISTENERREQ._serialized_end = 13342
    _RPORTFWDSTARTLISTENERREQ._serialized_start = 13345
    _RPORTFWDSTARTLISTENERREQ._serialized_end = 13491
    _RPORTFWDLISTENER._serialized_start = 13494
    _RPORTFWDLISTENER._serialized_end = 13646
    _RPORTFWDLISTENERS._serialized_start = 13648
    _RPORTFWDLISTENERS._serialized_end = 13752
    _RPORTFWDLISTENERSREQ._serialized_start = 13754
    _RPORTFWDLISTENERSREQ._serialized_end = 13812
    _RPORTFWD._serialized_start = 13814
    _RPORTFWD._serialized_end = 13930
    _RPORTFWDREQ._serialized_start = 13932
    _RPORTFWDREQ._serialized_end = 14049
# @@protoc_insertion_point(module_scope)



"""
    Sliver Implant Framework
    Copyright (C) 2021  Bishop Fox

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
from __future__ import annotations

import json
import os
from typing import Type, Union


class SliverClientConfig(object):
    """
    This class parses and represents Sliver operator configuration files, typically this class is automatically
    instantiated using one of the class methods :class:`SliverClientConfig.parse_config()` or :class:`SliverClientConfig.parse_config_file()` but can be directly
    instantiated too.

    :param operator: Operator name, note that this value is only used by the client and is ignored by the server.
    :param lhost: The listener host to connect to (i.e., the Sliver server host).
    :param lhost: The TCP port of the host listener (i.e., the TCP port of the Sliver "multiplayer" service).
    :param ca_certificate: The Sliver server certificate authority.
    :param certificate: The mTLS client certificate.
    :param private_key: The mTLS private key.
    :param token: The user's authentication token.

    :raises ValueError: A parameter contained an invalid value.
    """

    def __init__(
        self,
        operator: str,
        lhost: str,
        lport: int,
        ca_certificate: str,
        certificate: str,
        private_key: str,
        token: str,
    ):
        self.operator = operator
        self.lhost = lhost
        if not 0 < lport < 65535:
            raise ValueError("Invalid lport %d" % lport)
        self.lport = lport
        self.ca_certificate = ca_certificate
        self.certificate = certificate
        self.private_key = private_key
        self.token = token

    def __str__(self):
        return "%s@%s%d" % (
            self.operator,
            self.lhost,
            self.lport,
        )

    def __repr__(self):
        return "<Operator: %s, Lhost: %s, Lport: %d, CA: %s, Cert: %s>" % (
            self.operator,
            self.lhost,
            self.lport,
            self.ca_certificate,
            self.certificate,
        )

    @classmethod
    def parse_config(cls, data: Union[str, bytes]) -> SliverClientConfig:
        """Parses the content of a Sliver operator configuration file and
        returns the instantiated :class:`SliverClientConfig`

        :param data: The Sliver operator configuration file content.
        :type data: Union[str, bytes]
        :return: An instantiated :class:`SliverClientConfig` object.
        :rtype: SliverClientConfig
        """
        return cls(**json.loads(data))

    @classmethod
    def parse_config_file(cls, filepath: os.PathLike[str]) -> SliverClientConfig:
        """Parse a given file path as a Sliver operator configuration file.

        :param filepath: File system path to an operator configuration file.
        :type filepath: str
        :return: An instantiated :class:`SliverClientConfig` object.
        :rtype: SliverClientConfig
        """
        with open(filepath, "r") as fp:
            data = fp.read()
        return cls.parse_config(data)



from .pb.commonpb.common_pb2 import Request
from .pb.rpcpb.services_pb2_grpc import SliverRPCStub

try:
    from typing import Protocol
except ImportError:
    from typing_extensions import Protocol


class PbWithRequestProp(Protocol):  # type: ignore
    """Protocol for protobuf with Request field"""

    @property
    def Request(self) -> Request:
        ...


class InteractiveObject(Protocol):  # type: ignore
    """Protocol for objects with interactive methods"""

    @property
    def timeout(self) -> int:
        ...

    @property
    def _stub(self) -> SliverRPCStub:
        ...

    def _request(self, pb: PbWithRequestProp) -> PbWithRequestProp:
        ...



"""
    Sliver Implant Framework
    Copyright (C) 2022  Bishop Fox

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import asyncio
import functools
import logging
from typing import Any, Dict, List, Tuple

import grpc

from ._protocols import PbWithRequestProp
from .interactive import BaseInteractiveCommands
from .pb.rpcpb.services_pb2_grpc import SliverRPCStub
from .protobuf import client_pb2, common_pb2, sliver_pb2


class BaseBeacon:
    def __init__(
        self,
        beacon: client_pb2.Beacon,
        channel: grpc.aio.Channel,
        timeout: int = 60,
    ):
        """Base class for Beacon classes.

        :param beacon: Beacon protobuf object.
        :type beacon: client_pb2.Beacon
        :param channel: A gRPC channel.
        :type channel: grpc.aio.Channel
        :param timeout: Seconds to wait for timeout, defaults to TIMEOUT
        :type timeout: int, optional
        """
        self._log = logging.getLogger(self.__class__.__name__)
        self._channel = channel
        self._beacon = beacon
        self._stub = SliverRPCStub(channel)
        self.timeout = timeout
        self.beacon_tasks: Dict[str, Tuple[asyncio.Future, Any]] = {}
        asyncio.get_event_loop().create_task(self.taskresult_events())

    @property
    def beacon_id(self) -> str:
        """Beacon ID"""
        return self._beacon.ID

    @property
    def name(self) -> str:
        """Beacon name"""
        return self._beacon.Name

    @property
    def hostname(self) -> str:
        """Beacon hostname"""
        return self._beacon.Hostname

    @property
    def uuid(self) -> str:
        """Beacon UUID"""
        return self._beacon.UUID

    @property
    def username(self) -> str:
        """Username"""
        return self._beacon.Username

    @property
    def uid(self) -> str:
        """User ID"""
        return self._beacon.UID

    @property
    def gid(self) -> str:
        """Group ID"""
        return self._beacon.GID

    @property
    def os(self) -> str:
        """Operating system"""
        return self._beacon.OS

    @property
    def arch(self) -> str:
        """Architecture"""
        return self._beacon.Arch

    @property
    def transport(self) -> str:
        """Transport Method"""
        return self._beacon.Transport

    @property
    def remote_address(self) -> str:
        """Remote address"""
        return self._beacon.RemoteAddress

    @property
    def pid(self) -> int:
        """Process ID"""
        return self._beacon.PID

    @property
    def filename(self) -> str:
        """Beacon filename"""
        return self._beacon.Filename

    @property
    def last_checkin(self) -> int:
        """Last check in time"""
        return self._beacon.LastCheckin

    @property
    def active_c2(self) -> str:
        """Active C2"""
        return self._beacon.ActiveC2

    @property
    def version(self) -> str:
        """Version"""
        return self._beacon.Version

    @property
    def reconnect_interval(self) -> int:
        """Reconnect interval"""
        return self._beacon.ReconnectInterval

    def _request(self, pb: PbWithRequestProp):
        """
        Set request attributes based on current beacon, I'd prefer to return a generic Request
        object, but protobuf for whatever reason doesn't let you assign this type of field directly.

        `pb` in this case is any protobuf message with a .Request field.

        :param pb: A protobuf request object.
        """
        pb.Request.BeaconID = self._beacon.ID
        pb.Request.Timeout = self.timeout - 1
        pb.Request.Async = True
        return pb

    async def taskresult_events(self):
        """
        Monitor task events for results, resolve futures for any results
        we get back.
        """
        async for event in self._stub.Events(common_pb2.Empty()):
            if event.EventType != "beacon-taskresult":
                continue
            try:
                beacon_task = client_pb2.BeaconTask()
                beacon_task.ParseFromString(event.Data)
                if beacon_task.ID not in self.beacon_tasks:
                    continue
                task_content = await self._stub.GetBeaconTaskContent(
                    client_pb2.BeaconTask(ID=beacon_task.ID)
                )
                task_future, pb_object = self.beacon_tasks[beacon_task.ID]
                del self.beacon_tasks[beacon_task.ID]
                if pb_object is not None:
                    result = pb_object()
                    result.ParseFromString(task_content.Response)
                else:
                    result = None
                task_future.set_result(result)
            except Exception as err:
                self._log.exception(err)


def beacon_taskresult(pb_object: Any):
    """
    Wraps a class method to return a future that resolves when the
    beacon task result is available.
    """

    def func(method):
        @functools.wraps(method)
        async def wrapper(self, *args, **kwargs):
            task_response = await method(self, *args, **kwargs)
            self.beacon_tasks[task_response.Response.TaskID] = (
                asyncio.Future(),
                pb_object,
            )
            return self.beacon_tasks[task_response.Response.TaskID][0]

        return wrapper

    return func


class InteractiveBeacon(BaseBeacon, BaseInteractiveCommands):

    """Wrap all commands that can be executed against a beacon mode implant"""

    async def interactive_session(self):
        pass

    # ----------------  Wrapped super() commands ----------------

    @beacon_taskresult(sliver_pb2.Ping)
    async def ping(self, *args, **kwargs) -> sliver_pb2.Ping:
        return await super().ping(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Ps)
    async def ps(self, *args, **kwargs) -> List[common_pb2.Process]:
        return await super().ps(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Terminate)
    async def terminate(self, *args, **kwargs) -> sliver_pb2.Terminate:
        return await super().terminate(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Ifconfig)
    async def ifconfig(self, *args, **kwargs) -> sliver_pb2.Ifconfig:
        return await super().ifconfig(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Netstat)
    async def netstat(self, *args, **kwargs) -> sliver_pb2.Netstat:
        return await super().netstat(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Ls)
    async def ls(self, *args, **kwargs) -> sliver_pb2.Ls:
        return await super().ls(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Pwd)
    async def cd(self, *args, **kwargs) -> sliver_pb2.Pwd:
        return await super().cd(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Pwd)
    async def pwd(self, *args, **kwargs) -> sliver_pb2.Pwd:
        return await super().pwd(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Rm)
    async def rm(self, *args, **kwargs) -> sliver_pb2.Rm:
        return await super().rm(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Mkdir)
    async def mkdir(self, *args, **kwargs) -> sliver_pb2.Mkdir:
        return await super().mkdir(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Download)
    async def download(self, *args, **kwargs) -> sliver_pb2.Download:
        return await super().download(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Upload)
    async def upload(self, *args, **kwargs) -> sliver_pb2.Upload:
        return await super().upload(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.ProcessDump)
    async def process_dump(self, *args, **kwargs) -> sliver_pb2.ProcessDump:
        return await super().process_dump(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.RunAs)
    async def run_as(self, *args, **kwargs) -> sliver_pb2.RunAs:
        return await super().run_as(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Impersonate)
    async def impersonate(self, *args, **kwargs) -> sliver_pb2.Impersonate:
        return await super().impersonate(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.RevToSelf)
    async def revert_to_self(self, *args, **kwargs) -> sliver_pb2.RevToSelf:
        return await super().revert_to_self(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.GetSystem)
    async def get_system(self, *args, **kwargs) -> sliver_pb2.GetSystem:
        return await super().get_system(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Task)
    async def execute_shellcode(self, *args, **kwargs) -> sliver_pb2.Task:
        return await super().execute_shellcode(*args, **kwargs)

    @beacon_taskresult(None)
    async def msf(self, *args, **kwargs) -> None:
        return await super().msf(*args, **kwargs)

    @beacon_taskresult(None)
    async def msf_remote(self, *args, **kwargs) -> None:
        return await super().msf_remote(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.ExecuteAssembly)
    async def execute_assembly(self, *args, **kwargs) -> sliver_pb2.ExecuteAssembly:
        return await super().execute_assembly(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Migrate)
    async def migrate(self, *args, **kwargs) -> sliver_pb2.Migrate:
        return await super().migrate(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Execute)
    async def execute(self, *args, **kwargs) -> sliver_pb2.Execute:
        return await super().execute(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Sideload)
    async def sideload(self, *args, **kwargs) -> sliver_pb2.Sideload:
        return await super().sideload(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.SpawnDll)
    async def spawn_dll(self, *args, **kwargs) -> sliver_pb2.SpawnDll:
        return await super().spawn_dll(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.Screenshot)
    async def screenshot(self, *args, **kwargs) -> sliver_pb2.Screenshot:
        return await super().screenshot(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.MakeToken)
    async def make_token(self, *args, **kwargs) -> sliver_pb2.MakeToken:
        return await super().make_token(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.EnvInfo)
    async def get_env(self, *args, **kwargs) -> sliver_pb2.EnvInfo:
        return await super().get_env(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.SetEnv)
    async def set_env(self, *args, **kwargs) -> sliver_pb2.SetEnv:
        return await super().set_env(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.RegistryRead)
    async def registry_read(self, *args, **kwargs) -> sliver_pb2.RegistryRead:
        return await super().registry_read(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.RegistryWrite)
    async def registry_write(self, *args, **kwargs) -> sliver_pb2.RegistryWrite:
        return await super().registry_write(*args, **kwargs)

    @beacon_taskresult(sliver_pb2.RegistryCreateKey)
    async def registry_create_key(
        self, *args, **kwargs
    ) -> sliver_pb2.RegistryCreateKey:
        return await super().registry_create_key(*args, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clientpb/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..commonpb import common_pb2 as commonpb_dot_common__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x63lientpb/client.proto\x12\x08\x63lientpb\x1a\x15\x63ommonpb/common.proto"\x83\x01\n\x07Version\x12\r\n\x05Major\x18\x01 \x01(\x05\x12\r\n\x05Minor\x18\x02 \x01(\x05\x12\r\n\x05Patch\x18\x03 \x01(\x05\x12\x0e\n\x06\x43ommit\x18\x04 \x01(\t\x12\r\n\x05\x44irty\x18\x05 \x01(\x08\x12\x12\n\nCompiledAt\x18\x06 \x01(\x03\x12\n\n\x02OS\x18\x07 \x01(\t\x12\x0c\n\x04\x41rch\x18\x08 \x01(\t"\xb2\x03\n\x07Session\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08Hostname\x18\x03 \x01(\t\x12\x0c\n\x04UUID\x18\x04 \x01(\t\x12\x10\n\x08Username\x18\x05 \x01(\t\x12\x0b\n\x03UID\x18\x06 \x01(\t\x12\x0b\n\x03GID\x18\x07 \x01(\t\x12\n\n\x02OS\x18\x08 \x01(\t\x12\x0c\n\x04\x41rch\x18\t \x01(\t\x12\x11\n\tTransport\x18\n \x01(\t\x12\x15\n\rRemoteAddress\x18\x0b \x01(\t\x12\x0b\n\x03PID\x18\x0c \x01(\x05\x12\x10\n\x08\x46ilename\x18\r \x01(\t\x12\x13\n\x0bLastCheckin\x18\x0e \x01(\x03\x12\x10\n\x08\x41\x63tiveC2\x18\x0f \x01(\t\x12\x0f\n\x07Version\x18\x10 \x01(\t\x12\x0f\n\x07\x45vasion\x18\x11 \x01(\x08\x12\x0e\n\x06IsDead\x18\x12 \x01(\x08\x12\x19\n\x11ReconnectInterval\x18\x13 \x01(\x03\x12\x10\n\x08ProxyURL\x18\x14 \x01(\t\x12\x0e\n\x06\x42urned\x18\x16 \x01(\x08\x12\x12\n\nExtensions\x18\x17 \x03(\t\x12\x0e\n\x06PeerID\x18\x19 \x01(\x03\x12\x0e\n\x06Locale\x18\x1a \x01(\t\x12\x14\n\x0c\x46irstContact\x18\x1b \x01(\x03"\xf5\x03\n\x06\x42\x65\x61\x63on\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08Hostname\x18\x03 \x01(\t\x12\x0c\n\x04UUID\x18\x04 \x01(\t\x12\x10\n\x08Username\x18\x05 \x01(\t\x12\x0b\n\x03UID\x18\x06 \x01(\t\x12\x0b\n\x03GID\x18\x07 \x01(\t\x12\n\n\x02OS\x18\x08 \x01(\t\x12\x0c\n\x04\x41rch\x18\t \x01(\t\x12\x11\n\tTransport\x18\n \x01(\t\x12\x15\n\rRemoteAddress\x18\x0b \x01(\t\x12\x0b\n\x03PID\x18\x0c \x01(\x05\x12\x10\n\x08\x46ilename\x18\r \x01(\t\x12\x13\n\x0bLastCheckin\x18\x0e \x01(\x03\x12\x10\n\x08\x41\x63tiveC2\x18\x0f \x01(\t\x12\x0f\n\x07Version\x18\x10 \x01(\t\x12\x0f\n\x07\x45vasion\x18\x11 \x01(\x08\x12\x0e\n\x06IsDead\x18\x12 \x01(\x08\x12\x10\n\x08ProxyURL\x18\x14 \x01(\t\x12\x19\n\x11ReconnectInterval\x18\x15 \x01(\x03\x12\x10\n\x08Interval\x18\x16 \x01(\x03\x12\x0e\n\x06Jitter\x18\x17 \x01(\x03\x12\x0e\n\x06\x42urned\x18\x18 \x01(\x08\x12\x13\n\x0bNextCheckin\x18\x19 \x01(\x03\x12\x12\n\nTasksCount\x18\x1a \x01(\x03\x12\x1b\n\x13TasksCountCompleted\x18\x1b \x01(\x03\x12\x0e\n\x06Locale\x18\x1c \x01(\t\x12\x14\n\x0c\x46irstContact\x18\x1d \x01(\x03",\n\x07\x42\x65\x61\x63ons\x12!\n\x07\x42\x65\x61\x63ons\x18\x02 \x03(\x0b\x32\x10.clientpb.Beacon"\xa9\x01\n\nBeaconTask\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x10\n\x08\x42\x65\x61\x63onID\x18\x02 \x01(\t\x12\x11\n\tCreatedAt\x18\x03 \x01(\x03\x12\r\n\x05State\x18\x04 \x01(\t\x12\x0e\n\x06SentAt\x18\x05 \x01(\x03\x12\x13\n\x0b\x43ompletedAt\x18\x06 \x01(\x03\x12\x0f\n\x07Request\x18\x07 \x01(\x0c\x12\x10\n\x08Response\x18\x08 \x01(\x0c\x12\x13\n\x0b\x44\x65scription\x18\t \x01(\t"D\n\x0b\x42\x65\x61\x63onTasks\x12\x10\n\x08\x42\x65\x61\x63onID\x18\x01 \x01(\t\x12#\n\x05Tasks\x18\x02 \x03(\x0b\x32\x14.clientpb.BeaconTask";\n\tImplantC2\x12\x10\n\x08Priority\x18\x01 \x01(\r\x12\x0b\n\x03URL\x18\x02 \x01(\t\x12\x0f\n\x07Options\x18\x03 \x01(\t"\x98\x07\n\rImplantConfig\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x10\n\x08IsBeacon\x18\x02 \x01(\x08\x12\x16\n\x0e\x42\x65\x61\x63onInterval\x18\x03 \x01(\x03\x12\x14\n\x0c\x42\x65\x61\x63onJitter\x18\x04 \x01(\x03\x12\x0c\n\x04GOOS\x18\x05 \x01(\t\x12\x0e\n\x06GOARCH\x18\x06 \x01(\t\x12\x0c\n\x04Name\x18\x07 \x01(\t\x12\r\n\x05\x44\x65\x62ug\x18\x08 \x01(\x08\x12\x0f\n\x07\x45vasion\x18\t \x01(\x08\x12\x18\n\x10ObfuscateSymbols\x18\n \x01(\x08\x12\x12\n\nMtlsCACert\x18\x14 \x01(\t\x12\x10\n\x08MtlsCert\x18\x15 \x01(\t\x12\x0f\n\x07MtlsKey\x18\x16 \x01(\t\x12\x14\n\x0c\x45\x43\x43PublicKey\x18\x17 \x01(\t\x12\x15\n\rECCPrivateKey\x18\x18 \x01(\t\x12\x1d\n\x15\x45\x43\x43PublicKeySignature\x18\x19 \x01(\t\x12\x1f\n\x17MinisignServerPublicKey\x18\x1a \x01(\t\x12\x18\n\x10WGImplantPrivKey\x18\x1e \x01(\t\x12\x16\n\x0eWGServerPubKey\x18\x1f \x01(\t\x12\x13\n\x0bWGPeerTunIP\x18  \x01(\t\x12\x19\n\x11WGKeyExchangePort\x18! \x01(\r\x12\x16\n\x0eWGTcpCommsPort\x18" \x01(\r\x12\x19\n\x11ReconnectInterval\x18( \x01(\x03\x12\x1b\n\x13MaxConnectionErrors\x18) \x01(\r\x12\x13\n\x0bPollTimeout\x18* \x01(\x03\x12\x1f\n\x02\x43\x32\x18\x32 \x03(\x0b\x32\x13.clientpb.ImplantC2\x12\x15\n\rCanaryDomains\x18\x33 \x03(\t\x12\x1a\n\x12\x43onnectionStrategy\x18\x34 \x01(\t\x12\x19\n\x11LimitDomainJoined\x18< \x01(\x08\x12\x15\n\rLimitDatetime\x18= \x01(\t\x12\x15\n\rLimitHostname\x18> \x01(\t\x12\x15\n\rLimitUsername\x18? \x01(\t\x12\x17\n\x0fLimitFileExists\x18@ \x01(\t\x12\x13\n\x0bLimitLocale\x18\x41 \x01(\t\x12&\n\x06\x46ormat\x18\x64 \x01(\x0e\x32\x16.clientpb.OutputFormat\x12\x13\n\x0bIsSharedLib\x18\x65 \x01(\x08\x12\x10\n\x08\x46ileName\x18\x66 \x01(\t\x12\x11\n\tIsService\x18g \x01(\x08\x12\x13\n\x0bIsShellcode\x18h \x01(\x08\x12\x11\n\tRunAtLoad\x18i \x01(\x08"a\n\x15\x45xternalImplantConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig\x12\x11\n\tOTPSecret\x18\x03 \x01(\t"\\\n\x15\x45xternalImplantBinary\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x17\n\x0fImplantConfigID\x18\x02 \x01(\t\x12\x1c\n\x04\x46ile\x18\x03 \x01(\x0b\x32\x0e.commonpb.File"\x8f\x01\n\rImplantBuilds\x12\x35\n\x07\x43onfigs\x18\x01 \x03(\x0b\x32$.clientpb.ImplantBuilds.ConfigsEntry\x1aG\n\x0c\x43onfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig:\x02\x38\x01"V\n\x0e\x43ompilerTarget\x12\x0c\n\x04GOOS\x18\x01 \x01(\t\x12\x0e\n\x06GOARCH\x18\x02 \x01(\t\x12&\n\x06\x46ormat\x18\x03 \x01(\x0e\x32\x16.clientpb.OutputFormat"Z\n\rCrossCompiler\x12\x12\n\nTargetGOOS\x18\x01 \x01(\t\x12\x14\n\x0cTargetGOARCH\x18\x02 \x01(\t\x12\x0e\n\x06\x43\x43Path\x18\x03 \x01(\t\x12\x0f\n\x07\x43XXPath\x18\x04 \x01(\t"\xba\x01\n\x08\x43ompiler\x12\x0c\n\x04GOOS\x18\x01 \x01(\t\x12\x0e\n\x06GOARCH\x18\x02 \x01(\t\x12)\n\x07Targets\x18\x03 \x03(\x0b\x32\x18.clientpb.CompilerTarget\x12/\n\x0e\x43rossCompilers\x18\x04 \x03(\x0b\x32\x17.clientpb.CrossCompiler\x12\x34\n\x12UnsupportedTargets\x18\x05 \x03(\x0b\x32\x18.clientpb.CompilerTarget"\x19\n\tDeleteReq\x12\x0c\n\x04Name\x18\x01 \x01(\t"\x81\x01\n\tDNSCanary\x12\x13\n\x0bImplantName\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x11\n\tTriggered\x18\x03 \x01(\x08\x12\x16\n\x0e\x46irstTriggered\x18\x04 \x01(\t\x12\x15\n\rLatestTrigger\x18\x05 \x01(\t\x12\r\n\x05\x43ount\x18\x06 \x01(\r"1\n\x08\x43\x61naries\x12%\n\x08\x43\x61naries\x18\x01 \x03(\x0b\x32\x13.clientpb.DNSCanary"\x18\n\nUniqueWGIP\x12\n\n\x02IP\x18\x01 \x01(\t"G\n\x0eImplantProfile\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig"=\n\x0fImplantProfiles\x12*\n\x08Profiles\x18\x01 \x03(\x0b\x32\x18.clientpb.ImplantProfile"$\n\rRegenerateReq\x12\x13\n\x0bImplantName\x18\x01 \x01(\t"e\n\x03Job\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x03 \x01(\t\x12\x10\n\x08Protocol\x18\x04 \x01(\t\x12\x0c\n\x04Port\x18\x05 \x01(\r\x12\x0f\n\x07\x44omains\x18\x06 \x03(\t"%\n\x04Jobs\x12\x1d\n\x06\x41\x63tive\x18\x01 \x03(\x0b\x32\r.clientpb.Job"\x18\n\nKillJobReq\x12\n\n\x02ID\x18\x01 \x01(\r"&\n\x07KillJob\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0f\n\x07Success\x18\x02 \x01(\x08"A\n\x0fMTLSListenerReq\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x12\n\nPersistent\x18\x03 \x01(\x08"\x1d\n\x0cMTLSListener\x12\r\n\x05JobID\x18\x01 \x01(\r"n\n\rWGListenerReq\x12\x0c\n\x04Host\x18\x06 \x01(\t\x12\x0c\n\x04Port\x18\x01 \x01(\r\x12\r\n\x05TunIP\x18\x02 \x01(\t\x12\r\n\x05NPort\x18\x03 \x01(\r\x12\x0f\n\x07KeyPort\x18\x04 \x01(\r\x12\x12\n\nPersistent\x18\x05 \x01(\x08"\x1b\n\nWGListener\x12\r\n\x05JobID\x18\x01 \x01(\r"w\n\x0e\x44NSListenerReq\x12\x0f\n\x07\x44omains\x18\x01 \x03(\t\x12\x10\n\x08\x43\x61naries\x18\x02 \x01(\x08\x12\x0c\n\x04Host\x18\x03 \x01(\t\x12\x0c\n\x04Port\x18\x04 \x01(\r\x12\x12\n\nPersistent\x18\x05 \x01(\x08\x12\x12\n\nEnforceOTP\x18\x06 \x01(\x08"\x1c\n\x0b\x44NSListener\x12\r\n\x05JobID\x18\x01 \x01(\r"\xf7\x01\n\x0fHTTPListenerReq\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0e\n\x06Secure\x18\x04 \x01(\x08\x12\x0f\n\x07Website\x18\x05 \x01(\t\x12\x0c\n\x04\x43\x65rt\x18\x06 \x01(\x0c\x12\x0b\n\x03Key\x18\x07 \x01(\x0c\x12\x0c\n\x04\x41\x43ME\x18\x08 \x01(\x08\x12\x12\n\nPersistent\x18\t \x01(\x08\x12\x12\n\nEnforceOTP\x18\n \x01(\x08\x12\x17\n\x0fLongPollTimeout\x18\x0b \x01(\x03\x12\x16\n\x0eLongPollJitter\x18\x0c \x01(\x03\x12\x15\n\rRandomizeJARM\x18\r \x01(\x08"E\n\rNamedPipesReq\x12\x10\n\x08PipeName\x18\x10 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"P\n\nNamedPipes\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"B\n\x0bTCPPivotReq\x12\x0f\n\x07\x41\x64\x64ress\x18\x10 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"N\n\x08TCPPivot\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\x1d\n\x0cHTTPListener\x12\r\n\x05JobID\x18\x01 \x01(\r"/\n\x08Sessions\x12#\n\x08Sessions\x18\x01 \x03(\x0b\x32\x11.clientpb.Session">\n\tRenameReq\x12\x11\n\tSessionID\x18\x01 \x01(\t\x12\x10\n\x08\x42\x65\x61\x63onID\x18\x02 \x01(\t\x12\x0c\n\x04Name\x18\x03 \x01(\t"6\n\x0bGenerateReq\x12\'\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x17.clientpb.ImplantConfig"(\n\x08Generate\x12\x1c\n\x04\x46ile\x18\x01 \x01(\x0b\x32\x0e.commonpb.File"\x80\x01\n\x06MSFReq\x12\x0f\n\x07Payload\x18\x01 \x01(\t\x12\r\n\x05LHost\x18\x02 \x01(\t\x12\r\n\x05LPort\x18\x03 \x01(\r\x12\x0f\n\x07\x45ncoder\x18\x04 \x01(\t\x12\x12\n\nIterations\x18\x05 \x01(\x05\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x93\x01\n\x0cMSFRemoteReq\x12\x0f\n\x07Payload\x18\x01 \x01(\t\x12\r\n\x05LHost\x18\x02 \x01(\t\x12\r\n\x05LPort\x18\x03 \x01(\r\x12\x0f\n\x07\x45ncoder\x18\x04 \x01(\t\x12\x12\n\nIterations\x18\x05 \x01(\x05\x12\x0b\n\x03PID\x18\x08 \x01(\r\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x91\x01\n\x11StagerListenerReq\x12)\n\x08Protocol\x18\x01 \x01(\x0e\x32\x17.clientpb.StageProtocol\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12\x0c\n\x04\x43\x65rt\x18\x05 \x01(\x0c\x12\x0b\n\x03Key\x18\x06 \x01(\x0c\x12\x0c\n\x04\x41\x43ME\x18\x07 \x01(\x08"\x1f\n\x0eStagerListener\x12\r\n\x05JobID\x18\x01 \x01(\r"H\n\x0fShellcodeRDIReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x14\n\x0c\x46unctionName\x18\x02 \x01(\t\x12\x11\n\tArguments\x18\x03 \x01(\t"\x1c\n\x0cShellcodeRDI\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c"\x91\x01\n\x0cMsfStagerReq\x12\x0c\n\x04\x41rch\x18\x01 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0c\n\x04Host\x18\x04 \x01(\t\x12\n\n\x02OS\x18\x05 \x01(\t\x12)\n\x08Protocol\x18\x06 \x01(\x0e\x32\x17.clientpb.StageProtocol\x12\x10\n\x08\x42\x61\x64\x43hars\x18\x07 \x03(\t")\n\tMsfStager\x12\x1c\n\x04\x46ile\x18\x01 \x01(\x0b\x32\x0e.commonpb.File"s\n\x0cGetSystemReq\x12\x16\n\x0eHostingProcess\x18\x01 \x01(\t\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"f\n\nMigrateReq\x12\x0b\n\x03Pid\x18\x01 \x01(\r\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"5\n\x0f\x43reateTunnelReq\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"7\n\x0c\x43reateTunnel\x12\x11\n\tSessionID\x18\x01 \x01(\r\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01"J\n\x0e\x43loseTunnelReq\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"\x80\x01\n\x0fPivotGraphEntry\x12\x0e\n\x06PeerID\x18\x01 \x01(\x03\x12"\n\x07Session\x18\x02 \x01(\x0b\x32\x11.clientpb.Session\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12+\n\x08\x43hildren\x18\x04 \x03(\x0b\x32\x19.clientpb.PivotGraphEntry"9\n\nPivotGraph\x12+\n\x08\x43hildren\x18\x01 \x03(\x0b\x32\x19.clientpb.PivotGraphEntry"H\n\x06\x43lient\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12$\n\x08Operator\x18\x03 \x01(\x0b\x32\x12.clientpb.Operator"\x97\x01\n\x05\x45vent\x12\x11\n\tEventType\x18\x01 \x01(\t\x12"\n\x07Session\x18\x02 \x01(\x0b\x32\x11.clientpb.Session\x12\x1a\n\x03Job\x18\x03 \x01(\x0b\x32\r.clientpb.Job\x12 \n\x06\x43lient\x18\x04 \x01(\x0b\x32\x10.clientpb.Client\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\x0b\n\x03\x45rr\x18\x06 \x01(\t"2\n\tOperators\x12%\n\tOperators\x18\x01 \x03(\x0b\x32\x12.clientpb.Operator"(\n\x08Operator\x12\x0e\n\x06Online\x18\x01 \x01(\x08\x12\x0c\n\x04Name\x18\x02 \x01(\t"R\n\nWebContent\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0b\x43ontentType\x18\x02 \x01(\t\x12\x10\n\x04Size\x18\x03 \x01(\x04\x42\x02\x30\x01\x12\x0f\n\x07\x43ontent\x18\t \x01(\x0c"\xa5\x01\n\x11WebsiteAddContent\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12;\n\x08\x43ontents\x18\x02 \x03(\x0b\x32).clientpb.WebsiteAddContent.ContentsEntry\x1a\x45\n\rContentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.clientpb.WebContent:\x02\x38\x01"3\n\x14WebsiteRemoveContent\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Paths\x18\x02 \x03(\t"\x91\x01\n\x07Website\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x31\n\x08\x43ontents\x18\x02 \x03(\x0b\x32\x1f.clientpb.Website.ContentsEntry\x1a\x45\n\rContentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.clientpb.WebContent:\x02\x38\x01"/\n\x08Websites\x12#\n\x08Websites\x18\x01 \x03(\x0b\x32\x11.clientpb.Website"h\n\x0eWGClientConfig\x12\x14\n\x0cServerPubKey\x18\x01 \x01(\t\x12\x18\n\x10\x43lientPrivateKey\x18\x02 \x01(\t\x12\x14\n\x0c\x43lientPubKey\x18\x03 \x01(\t\x12\x10\n\x08\x43lientIP\x18\x04 \x01(\t"<\n\nCredential\x12\x0c\n\x04User\x18\x02 \x01(\t\x12\x10\n\x08Password\x18\x03 \x01(\t\x12\x0e\n\x06\x41PIKey\x18\x04 \x01(\t"\xe6\x01\n\x04Loot\x12 \n\x04Type\x18\x01 \x01(\x0e\x32\x12.clientpb.LootType\x12\x0e\n\x06LootID\x18\x02 \x01(\t\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x30\n\x0e\x43redentialType\x18\x04 \x01(\x0e\x32\x18.clientpb.CredentialType\x12(\n\nCredential\x18\x05 \x01(\x0b\x32\x14.clientpb.Credential\x12$\n\x08\x46ileType\x18\x06 \x01(\x0e\x32\x12.clientpb.FileType\x12\x1c\n\x04\x46ile\x18\t \x01(\x0b\x32\x0e.commonpb.File"\'\n\x07\x41llLoot\x12\x1c\n\x04Loot\x18\x01 \x03(\x0b\x32\x0e.clientpb.Loot"1\n\x03IOC\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x10\n\x08\x46ileHash\x18\x02 \x01(\t\x12\n\n\x02ID\x18\x03 \x01(\t"\x1f\n\rExtensionData\x12\x0e\n\x06Output\x18\x01 \x01(\t"\x89\x02\n\x04Host\x12\x10\n\x08Hostname\x18\x01 \x01(\t\x12\x10\n\x08HostUUID\x18\x02 \x01(\t\x12\x11\n\tOSVersion\x18\x03 \x01(\t\x12\x1b\n\x04IOCs\x18\x04 \x03(\x0b\x32\r.clientpb.IOC\x12\x38\n\rExtensionData\x18\x05 \x03(\x0b\x32!.clientpb.Host.ExtensionDataEntry\x12\x0e\n\x06Locale\x18\x06 \x01(\t\x12\x14\n\x0c\x46irstContact\x18\x07 \x01(\x03\x1aM\n\x12\x45xtensionDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.clientpb.ExtensionData:\x02\x38\x01")\n\x08\x41llHosts\x12\x1d\n\x05Hosts\x18\x01 \x03(\x0b\x32\x0e.clientpb.Host"\xa2\x01\n\x0c\x44llHijackReq\x12\x18\n\x10ReferenceDLLPath\x18\x01 \x01(\t\x12\x16\n\x0eTargetLocation\x18\x02 \x01(\t\x12\x14\n\x0cReferenceDLL\x18\x03 \x01(\x0c\x12\x11\n\tTargetDLL\x18\x04 \x01(\x0c\x12\x13\n\x0bProfileName\x18\x05 \x01(\t\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"1\n\tDllHijack\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xaf\x01\n\x12ShellcodeEncodeReq\x12+\n\x07\x45ncoder\x18\x01 \x01(\x0e\x32\x1a.clientpb.ShellcodeEncoder\x12\x14\n\x0c\x41rchitecture\x18\x02 \x01(\t\x12\x12\n\nIterations\x18\x03 \x01(\r\x12\x10\n\x08\x42\x61\x64\x43hars\x18\x04 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x08 \x01(\x0c\x12"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request"E\n\x0fShellcodeEncode\x12\x0c\n\x04\x44\x61ta\x18\x08 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response"\xa1\x01\n\x13ShellcodeEncoderMap\x12=\n\x08\x45ncoders\x18\x01 \x03(\x0b\x32+.clientpb.ShellcodeEncoderMap.EncodersEntry\x1aK\n\rEncodersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.clientpb.ShellcodeEncoder:\x02\x38\x01*X\n\x0cOutputFormat\x12\x0e\n\nSHARED_LIB\x10\x00\x12\r\n\tSHELLCODE\x10\x01\x12\x0e\n\nEXECUTABLE\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x0c\n\x08\x45XTERNAL\x10\x04*-\n\rStageProtocol\x12\x07\n\x03TCP\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02*.\n\x08LootType\x12\r\n\tLOOT_FILE\x10\x00\x12\x13\n\x0fLOOT_CREDENTIAL\x10\x01*M\n\x0e\x43redentialType\x12\x11\n\rNO_CREDENTIAL\x10\x00\x12\x11\n\rUSER_PASSWORD\x10\x01\x12\x0b\n\x07\x41PI_KEY\x10\x02\x12\x08\n\x04\x46ILE\x10\x03*-\n\x08\x46ileType\x12\x0b\n\x07NO_FILE\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x08\n\x04TEXT\x10\x02*&\n\x10ShellcodeEncoder\x12\x12\n\x0eSHIKATA_GA_NAI\x10\x00\x42/Z-github.com/bishopfox/sliver/protobuf/clientpbb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "clientpb.client_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z-github.com/bishopfox/sliver/protobuf/clientpb"
    _IMPLANTBUILDS_CONFIGSENTRY._options = None
    _IMPLANTBUILDS_CONFIGSENTRY._serialized_options = b"8\001"
    _CREATETUNNEL.fields_by_name["TunnelID"]._options = None
    _CREATETUNNEL.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _CLOSETUNNELREQ.fields_by_name["TunnelID"]._options = None
    _CLOSETUNNELREQ.fields_by_name["TunnelID"]._serialized_options = b"0\001"
    _WEBCONTENT.fields_by_name["Size"]._options = None
    _WEBCONTENT.fields_by_name["Size"]._serialized_options = b"0\001"
    _WEBSITEADDCONTENT_CONTENTSENTRY._options = None
    _WEBSITEADDCONTENT_CONTENTSENTRY._serialized_options = b"8\001"
    _WEBSITE_CONTENTSENTRY._options = None
    _WEBSITE_CONTENTSENTRY._serialized_options = b"8\001"
    _HOST_EXTENSIONDATAENTRY._options = None
    _HOST_EXTENSIONDATAENTRY._serialized_options = b"8\001"
    _SHELLCODEENCODERMAP_ENCODERSENTRY._options = None
    _SHELLCODEENCODERMAP_ENCODERSENTRY._serialized_options = b"8\001"
    _OUTPUTFORMAT._serialized_start = 8560
    _OUTPUTFORMAT._serialized_end = 8648
    _STAGEPROTOCOL._serialized_start = 8650
    _STAGEPROTOCOL._serialized_end = 8695
    _LOOTTYPE._serialized_start = 8697
    _LOOTTYPE._serialized_end = 8743
    _CREDENTIALTYPE._serialized_start = 8745
    _CREDENTIALTYPE._serialized_end = 8822
    _FILETYPE._serialized_start = 8824
    _FILETYPE._serialized_end = 8869
    _SHELLCODEENCODER._serialized_start = 8871
    _SHELLCODEENCODER._serialized_end = 8909
    _VERSION._serialized_start = 59
    _VERSION._serialized_end = 190
    _SESSION._serialized_start = 193
    _SESSION._serialized_end = 627
    _BEACON._serialized_start = 630
    _BEACON._serialized_end = 1131
    _BEACONS._serialized_start = 1133
    _BEACONS._serialized_end = 1177
    _BEACONTASK._serialized_start = 1180
    _BEACONTASK._serialized_end = 1349
    _BEACONTASKS._serialized_start = 1351
    _BEACONTASKS._serialized_end = 1419
    _IMPLANTC2._serialized_start = 1421
    _IMPLANTC2._serialized_end = 1480
    _IMPLANTCONFIG._serialized_start = 1483
    _IMPLANTCONFIG._serialized_end = 2403
    _EXTERNALIMPLANTCONFIG._serialized_start = 2405
    _EXTERNALIMPLANTCONFIG._serialized_end = 2502
    _EXTERNALIMPLANTBINARY._serialized_start = 2504
    _EXTERNALIMPLANTBINARY._serialized_end = 2596
    _IMPLANTBUILDS._serialized_start = 2599
    _IMPLANTBUILDS._serialized_end = 2742
    _IMPLANTBUILDS_CONFIGSENTRY._serialized_start = 2671
    _IMPLANTBUILDS_CONFIGSENTRY._serialized_end = 2742
    _COMPILERTARGET._serialized_start = 2744
    _COMPILERTARGET._serialized_end = 2830
    _CROSSCOMPILER._serialized_start = 2832
    _CROSSCOMPILER._serialized_end = 2922
    _COMPILER._serialized_start = 2925
    _COMPILER._serialized_end = 3111
    _DELETEREQ._serialized_start = 3113
    _DELETEREQ._serialized_end = 3138
    _DNSCANARY._serialized_start = 3141
    _DNSCANARY._serialized_end = 3270
    _CANARIES._serialized_start = 3272
    _CANARIES._serialized_end = 3321
    _UNIQUEWGIP._serialized_start = 3323
    _UNIQUEWGIP._serialized_end = 3347
    _IMPLANTPROFILE._serialized_start = 3349
    _IMPLANTPROFILE._serialized_end = 3420
    _IMPLANTPROFILES._serialized_start = 3422
    _IMPLANTPROFILES._serialized_end = 3483
    _REGENERATEREQ._serialized_start = 3485
    _REGENERATEREQ._serialized_end = 3521
    _JOB._serialized_start = 3523
    _JOB._serialized_end = 3624
    _JOBS._serialized_start = 3626
    _JOBS._serialized_end = 3663
    _KILLJOBREQ._serialized_start = 3665
    _KILLJOBREQ._serialized_end = 3689
    _KILLJOB._serialized_start = 3691
    _KILLJOB._serialized_end = 3729
    _MTLSLISTENERREQ._serialized_start = 3731
    _MTLSLISTENERREQ._serialized_end = 3796
    _MTLSLISTENER._serialized_start = 3798
    _MTLSLISTENER._serialized_end = 3827
    _WGLISTENERREQ._serialized_start = 3829
    _WGLISTENERREQ._serialized_end = 3939
    _WGLISTENER._serialized_start = 3941
    _WGLISTENER._serialized_end = 3968
    _DNSLISTENERREQ._serialized_start = 3970
    _DNSLISTENERREQ._serialized_end = 4089
    _DNSLISTENER._serialized_start = 4091
    _DNSLISTENER._serialized_end = 4119
    _HTTPLISTENERREQ._serialized_start = 4122
    _HTTPLISTENERREQ._serialized_end = 4369
    _NAMEDPIPESREQ._serialized_start = 4371
    _NAMEDPIPESREQ._serialized_end = 4440
    _NAMEDPIPES._serialized_start = 4442
    _NAMEDPIPES._serialized_end = 4522
    _TCPPIVOTREQ._serialized_start = 4524
    _TCPPIVOTREQ._serialized_end = 4590
    _TCPPIVOT._serialized_start = 4592
    _TCPPIVOT._serialized_end = 4670
    _HTTPLISTENER._serialized_start = 4672
    _HTTPLISTENER._serialized_end = 4701
    _SESSIONS._serialized_start = 4703
    _SESSIONS._serialized_end = 4750
    _RENAMEREQ._serialized_start = 4752
    _RENAMEREQ._serialized_end = 4814
    _GENERATEREQ._serialized_start = 4816
    _GENERATEREQ._serialized_end = 4870
    _GENERATE._serialized_start = 4872
    _GENERATE._serialized_end = 4912
    _MSFREQ._serialized_start = 4915
    _MSFREQ._serialized_end = 5043
    _MSFREMOTEREQ._serialized_start = 5046
    _MSFREMOTEREQ._serialized_end = 5193
    _STAGERLISTENERREQ._serialized_start = 5196
    _STAGERLISTENERREQ._serialized_end = 5341
    _STAGERLISTENER._serialized_start = 5343
    _STAGERLISTENER._serialized_end = 5374
    _SHELLCODERDIREQ._serialized_start = 5376
    _SHELLCODERDIREQ._serialized_end = 5448
    _SHELLCODERDI._serialized_start = 5450
    _SHELLCODERDI._serialized_end = 5478
    _MSFSTAGERREQ._serialized_start = 5481
    _MSFSTAGERREQ._serialized_end = 5626
    _MSFSTAGER._serialized_start = 5628
    _MSFSTAGER._serialized_end = 5669
    _GETSYSTEMREQ._serialized_start = 5671
    _GETSYSTEMREQ._serialized_end = 5786
    _MIGRATEREQ._serialized_start = 5788
    _MIGRATEREQ._serialized_end = 5890
    _CREATETUNNELREQ._serialized_start = 5892
    _CREATETUNNELREQ._serialized_end = 5945
    _CREATETUNNEL._serialized_start = 5947
    _CREATETUNNEL._serialized_end = 6002
    _CLOSETUNNELREQ._serialized_start = 6004
    _CLOSETUNNELREQ._serialized_end = 6078
    _PIVOTGRAPHENTRY._serialized_start = 6081
    _PIVOTGRAPHENTRY._serialized_end = 6209
    _PIVOTGRAPH._serialized_start = 6211
    _PIVOTGRAPH._serialized_end = 6268
    _CLIENT._serialized_start = 6270
    _CLIENT._serialized_end = 6342
    _EVENT._serialized_start = 6345
    _EVENT._serialized_end = 6496
    _OPERATORS._serialized_start = 6498
    _OPERATORS._serialized_end = 6548
    _OPERATOR._serialized_start = 6550
    _OPERATOR._serialized_end = 6590
    _WEBCONTENT._serialized_start = 6592
    _WEBCONTENT._serialized_end = 6674
    _WEBSITEADDCONTENT._serialized_start = 6677
    _WEBSITEADDCONTENT._serialized_end = 6842
    _WEBSITEADDCONTENT_CONTENTSENTRY._serialized_start = 6773
    _WEBSITEADDCONTENT_CONTENTSENTRY._serialized_end = 6842
    _WEBSITEREMOVECONTENT._serialized_start = 6844
    _WEBSITEREMOVECONTENT._serialized_end = 6895
    _WEBSITE._serialized_start = 6898
    _WEBSITE._serialized_end = 7043
    _WEBSITE_CONTENTSENTRY._serialized_start = 6773
    _WEBSITE_CONTENTSENTRY._serialized_end = 6842
    _WEBSITES._serialized_start = 7045
    _WEBSITES._serialized_end = 7092
    _WGCLIENTCONFIG._serialized_start = 7094
    _WGCLIENTCONFIG._serialized_end = 7198
    _CREDENTIAL._serialized_start = 7200
    _CREDENTIAL._serialized_end = 7260
    _LOOT._serialized_start = 7263
    _LOOT._serialized_end = 7493
    _ALLLOOT._serialized_start = 7495
    _ALLLOOT._serialized_end = 7534
    _IOC._serialized_start = 7536
    _IOC._serialized_end = 7585
    _EXTENSIONDATA._serialized_start = 7587
    _EXTENSIONDATA._serialized_end = 7618
    _HOST._serialized_start = 7621
    _HOST._serialized_end = 7886
    _HOST_EXTENSIONDATAENTRY._serialized_start = 7809
    _HOST_EXTENSIONDATAENTRY._serialized_end = 7886
    _ALLHOSTS._serialized_start = 7888
    _ALLHOSTS._serialized_end = 7929
    _DLLHIJACKREQ._serialized_start = 7932
    _DLLHIJACKREQ._serialized_end = 8094
    _DLLHIJACK._serialized_start = 8096
    _DLLHIJACK._serialized_end = 8145
    _SHELLCODEENCODEREQ._serialized_start = 8148
    _SHELLCODEENCODEREQ._serialized_end = 8323
    _SHELLCODEENCODE._serialized_start = 8325
    _SHELLCODEENCODE._serialized_end = 8394
    _SHELLCODEENCODERMAP._serialized_start = 8397
    _SHELLCODEENCODERMAP._serialized_end = 8558
    _SHELLCODEENCODERMAP_ENCODERSENTRY._serialized_start = 8483
    _SHELLCODEENCODERMAP_ENCODERSENTRY._serialized_end = 8558
# @@protoc_insertion_point(module_scope)
